timeintervaltools.calculate_mean_release_of_intervals
=====================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_mean_release_of_intervals.calculate_mean_release_of_intervals
